name: 🚨 Security Vulnerability
description: Report a security vulnerability
title: "🚨 [SECURITY] <title>"
labels: ["security"]
body:
  - type: textarea
    attributes:
      label: Vulnerability description
      description: Please describe the vulnerability in detail.
    validations:
      required: true
  - type: textarea
    attributes:
      label: Steps to reproduce
      description: How can we reproduce the vulnerability?
    validations:
      required: true
  - type: textarea
    attributes:
      label: Impact
      description: What is the potential impact of this vulnerability?
    validations:
      required: false
  - type: textarea
    attributes:
      label: Suggested mitigation
      description: Do you have any suggestions for how to fix this?
    validations:
      required: false
  - type: textarea
    attributes:
      label: Additional context
      description: Any other information you want to share?
    validations:
      required: false
